@@ -36,7 +36,7 @@ def go(squadron_dir, squadron_state_dir = None, config_file = None, node_name =
         dry_run -- whether or not to apply changes
     """
     try:
-        config = parse_config(config_file)
+        config = parse_config(log, config_file)
         log.debug("Got config {}".format(config))
 
         if squadron_state_dir is None:
@@ -65,10 +65,10 @@ def go(squadron_dir, squadron_state_dir = None, config_file = None, node_name =
                     True, status='ERROR', hostname=node_name, info={'info':True, 'message':str(e)})
         log.exception('Caught exception')
         raise e
-    else:
+    else: #executes on no exception
         if send_status and not dry_run and info:
             status.report_status(requests.session(), status_server, status_apikey, status_secret, str(uuid.uuid4()),
-                    True, status='OK', hostname=node_name, info=info)
+                True, status='OK', hostname=node_name, info=info)
 
 def _is_current_last(prefix, tempdir, last_run_dir):
     """
@@ -122,13 +122,14 @@ def _run_squadron(squadron_dir, squadron_state_dir, node_name, dont_rollback, dr
         dont_rollback -- if true, doesn't automatically rollback to the previous version
         dry_run -- whether or not to apply changes
     """
+    log.debug('entering _run_squadron')
     try:
         run_info = runinfo.get_last_run_info(squadron_state_dir, dry_run)
         last_run_dir = run_info['dir']
         last_run_sum = run_info['checksum']
         last_commit = run_info['commit']
     except KeyError:
-        log.debug("Looks like info.json is empty or malformated")
+        log.debug("Looks like info.json is empty or malformated") #Is this bad?
         last_run_dir = None
         last_run_sum = {}
         last_commit = None
@@ -151,7 +152,7 @@ def _run_squadron(squadron_dir, squadron_state_dir, node_name, dont_rollback, dr
 
     log.info("Staging directory: %s", new_dir)
     result = commit.apply(squadron_dir, node_name, new_dir, resources, dry_run)
-
+    log.debug("commit.apply returned: %s", result)
     # Is this different from the last time we ran?
     this_run_sum = walk_hash(new_dir)
 
@@ -162,7 +163,7 @@ def _run_squadron(squadron_dir, squadron_state_dir, node_name, dont_rollback, dr
         paths_changed, new_paths = hash_diff(last_run_sum, this_run_sum)
         if not dry_run:
             _deploy(squadron_dir, new_dir, last_run_dir, result,
-                    this_run_sum, last_run_sum, last_commit, dont_rollback)
+                    this_run_sum, last_run_sum, last_commit, dont_rollback, resources)
             info = {'dir': new_dir, 'commit':result, 'checksum': this_run_sum}
             log.debug("Writing run info to %s: %s", squadron_state_dir, info)
 
@@ -172,6 +173,10 @@ def _run_squadron(squadron_dir, squadron_state_dir, node_name, dont_rollback, dr
             return info
         else:
             log.info("Dry run changes")
+            actions, reactions = _get_action_reaction(squadron_dir, result)
+            log.info("%s actions, %s reactions", len(actions), len(reactions))
+            log.debug("Actions are: %s", actions)
+            log.debug("Reactions are: %s", reactions)
 
         log.info("===============")
         log.info("Paths changed:")
@@ -186,13 +191,7 @@ def _run_squadron(squadron_dir, squadron_state_dir, node_name, dont_rollback, dr
         log.info("Nothing changed.")
     return None
 
-@go_to_root
-def _deploy(squadron_dir, new_dir, last_dir, commit_info,
-        this_run_sum, last_run_sum, last_commit, dont_rollback):
-    log.info("Applying changes")
-    log.debug("Changes: %s", commit_info)
-    commit.commit(commit_info)
-
+def _get_action_reaction(squadron_dir, commit_info):
     actions = {}
     reactions = []
 
@@ -204,6 +203,16 @@ def _deploy(squadron_dir, new_dir, last_dir, commit_info,
             service_name, version))
         reactions.extend(service.get_reactions(squadron_dir,
             service_name, version))
+    return (actions, reactions)
+
+@go_to_root
+def _deploy(squadron_dir, new_dir, last_dir, commit_info,
+        this_run_sum, last_run_sum, last_commit, dont_rollback, resources):
+    log.info("Applying changes")
+    log.debug("Changes: %s", commit_info)
+    commit.commit(commit_info)
+
+    actions, reactions = _get_action_reaction(squadron_dir, commit_info)
 
     # Then react to the changes
     log.debug("Reacting to changes: %s actions and %s reactions to run",
@@ -214,7 +223,7 @@ def _deploy(squadron_dir, new_dir, last_dir, commit_info,
     log.debug("Paths changed: %s", paths_changed)
     log.debug("New paths: %s", new_paths)
 
-    service.react(actions, reactions, paths_changed, new_paths, new_dir)
+    service.react(actions, reactions, paths_changed, new_paths, new_dir, resources)
     # Now test
     try:
         _run_tests(squadron_dir, commit_info)
@@ -224,7 +233,7 @@ def _deploy(squadron_dir, new_dir, last_dir, commit_info,
             log.error("Rolling back to %s because tests failed", last_commit)
             # Flip around the paths changed and new_paths
             _deploy(squadron_dir, last_dir, None, last_commit, last_run_sum,
-                    {}, None, dont_rollback)
+                    {}, None, dont_rollback, resources)
         raise
 
 @go_to_root
